Module policy

Module policy 

Service lifecycle policy.

Structs

ServicePolicy
Per-service exit policy owned by the supervisor.

Enums

ErrorAction
Supervisor reaction to a service error when a retry path is not taken.
ExitAction
Supervisor reaction to a service exit.
RestartPolicy
Restart behavior applied when a service exits with ServiceOutcome::Error.